---
name: "\U0001F680 Feature Request"
about: I have an idea for Vetur
title: ''
labels: feature
assignees: ''

---

<!-- Check those before opening an issue -->

- [ ] I have searched through existing issues

## Feature Request

<!-- Please only describe one feature request in one single issue. -->
